How to share your models?
============

Once you have uploaded your model according to  this `toturial <https://scarches.readthedocs.io/en/latest/zenodo_pancreas_from_scratch.html>`_, please share
the information about the model and the data you have used by filling `this <https://docs.google.com/forms/d/1_j65-sRbHAGZsfDAXGVWLw4yEDe1czdtTCypfS6SPkw/edit?ts=5f02c493>`_ form.

.. note::
   Please make sure you have same set of genes as in the reference models wit same order.

Model database
==============

The list of pretrained models are available in `here <https://docs.google.com/spreadsheets/d/1WmF01XlXUCS2mZJPifwiM508XBX3aGhTLk2L6E1XPvc/edit?usp=sharing>`_.


